@@ -16,7 +16,6 @@ from kotti.util import _
 from kotti.util import ViewLink
 from kotti.views.util import EditFormView
 from kotti.views.util import AddFormView
-from kotti.views.util import disambiguate_name
 from kotti.views.util import ensure_view_selector
 from kotti.views.util import nodes_tree
 from kotti.util import title_to_name
@@ -80,7 +79,7 @@ def actions(context, request):
     if not is_root:
         actions.append(ViewLink('rename', title=_(u'Rename')))
         actions.append(ViewLink('delete', title=_(u'Delete')))
-    if len(context.children) > 1:
+    if len(context.children) >= 1:
         actions.append(ViewLink('order', title=_(u'Order')))
     return {'actions': [action for action in actions
                         if action.permitted(context, request)]}
@@ -118,9 +117,8 @@ def paste_node(context, request):
         copy = item.copy()
         name = copy.name
         if not name:  # for root
-            name = title_to_name(copy.title)
-        while name in context.keys():
-            name = disambiguate_name(name)
+            name = copy.title
+        name = title_to_name(name, blacklist=context.keys())
         copy.name = name
         context.children.append(copy)
     request.session.flash(_(u'${title} pasted.',
@@ -132,17 +130,14 @@ def paste_node(context, request):
 
 def order_node(context, request):
     P = request.POST
-    session = DBSession()
 
     if 'order-up' in P or 'order-down' in P:
         up, down = P.get('order-up'), P.get('order-down')
-        id = int(down or up)
+        child = DBSession.query(Node).get(int(down or up))
         if up is not None:
             mod = -1
         else:  # pragma: no cover
             mod = 1
-
-        child = session.query(Node).get(id)
         index = context.children.index(child)
         context.children.pop(index)
         context.children.insert(index + mod, child)
@@ -151,6 +146,20 @@ def order_node(context, request):
         if not request.is_xhr:
             return HTTPFound(location=request.url)
 
+    elif 'toggle-visibility' in P:
+        child = DBSession.query(Node).get(int(P['toggle-visibility']))
+        child.in_navigation ^= True
+        mapping = dict(title=child.title)
+        if child.in_navigation:
+            msg = _(u'${title} is now visible in the navigation.',
+                    mapping=mapping)
+        else:
+            msg = _(u'${title} is no longer visible in the navigation.',
+                    mapping=mapping)
+        request.session.flash(msg, 'success')
+        if not request.is_xhr:
+            return HTTPFound(location=request.url)
+
     return {}
 
 
@@ -172,9 +181,9 @@ def rename_node(context, request):
         if not name or not title:
             request.session.flash(_(u'Name and title are required.'), 'error')
         else:
-            context.name = name
+            context.name = name.replace('/','')
             context.title = title
-            request.session.flash(_(u'Item renamed'), 'success')
+            request.session.flash(_(u'Item renamed'),'success')
             location = resource_url(context, request)
             return HTTPFound(location=location)
     return {}
@@ -267,39 +276,39 @@ def includeme(config):
 
 def nodes_includeme(config):
     config.add_view(
-        'kotti.views.edit.copy_node',
+        copy_node,
         name='copy',
         permission='edit',
         )
 
     config.add_view(
-        'kotti.views.edit.cut_node',
+        cut_node,
         name='cut',
         permission='edit',
         )
 
     config.add_view(
-        'kotti.views.edit.paste_node',
+        paste_node,
         name='paste',
         permission='edit',
         )
 
     config.add_view(
-        'kotti.views.edit.order_node',
+        order_node,
         name='order',
         permission='edit',
         renderer='kotti:templates/edit/order.pt',
         )
 
     config.add_view(
-        'kotti.views.edit.delete_node',
+        delete_node,
         name='delete',
         permission='edit',
         renderer='kotti:templates/edit/delete.pt',
         )
 
     config.add_view(
-        'kotti.views.edit.rename_node',
+        rename_node,
         name='rename',
         permission='edit',
         renderer='kotti:templates/edit/rename.pt',
