@@ -1,6 +1,7 @@
 from datetime import datetime
 
 import colander
+from deform import Button
 from deform import Form
 from deform import ValidationFailure
 from deform.widget import CheckedPasswordWidget
@@ -16,8 +17,8 @@ from pyramid.url import resource_url
 
 from kotti.message import validate_token
 from kotti.message import send_set_password
-from kotti.resources import get_root
 from kotti.security import get_principals
+from kotti.util import _
 from kotti.views.util import template_api
 
 def _find_user(login):
@@ -35,8 +36,6 @@ def _find_user(login):
                 return p
 
 def login(context, request):
-    root = get_root(request)
-    api = template_api(root, request)
     principals = get_principals()
 
     came_from = request.params.get(
@@ -44,7 +43,7 @@ def login(context, request):
     login, password = u'', u''
 
     if 'submit' in request.POST:
-        login = request.params['login']
+        login = request.params['login'].lower()
         password = request.params['password']
         user = _find_user(login)
 
@@ -52,25 +51,25 @@ def login(context, request):
             principals.validate_password(password, user.password)):
             headers = remember(request, login)
             request.session.flash(
-                u"Welcome, %s!" % user.title or user.name, 'success')
+                _(u"Welcome, ${user}!",
+                  mapping=dict(user=user.title or user.name)), 'success')
             user.last_login_date = datetime.now()
             return HTTPFound(location=came_from, headers=headers)
-        request.session.flash(u"Login failed.", 'error')
+        request.session.flash(_(u"Login failed."), 'error')
 
     if 'reset-password' in request.POST:
         login = request.params['login']
         user = _find_user(login)
         if user is not None:
             send_set_password(user, request, templates='reset-password')
-            request.session.flash(
+            request.session.flash(_(
                 u"You should receive an email with a link to reset your "
-                u"password momentarily.", 'success')
+                u"password momentarily."), 'success')
         else:
             request.session.flash(
-                "That username or email is not known to us.", 'error')
+                _(u"That username or email is not known to us."), 'error')
 
     return {
-        'api': api,
         'url': request.application_url + '/@@login',
         'came_from': came_from,
         'login': login,
@@ -79,13 +78,14 @@ def login(context, request):
 
 def logout(context, request):
     headers = forget(request)
-    request.session.flash(u"You have been logged out.")
+    request.session.flash(_(u"You have been logged out."))
     location = request.params.get('came_from', request.application_url)
     return HTTPFound(location=location, headers=headers)
 
 class SetPasswordSchema(colander.MappingSchema):
     password = colander.SchemaNode(
         colander.String(),
+        title=_(u'Password'),
         validator=colander.Length(min=5),
         widget=CheckedPasswordWidget(),
         )
@@ -95,6 +95,7 @@ class SetPasswordSchema(colander.MappingSchema):
         )
     email = colander.SchemaNode(
         colander.String(),
+        title=_(u'Email'),
         widget=HiddenWidget(),
         )
     continue_to = colander.SchemaNode(
@@ -104,15 +105,15 @@ class SetPasswordSchema(colander.MappingSchema):
         )
 
 def set_password(context, request,
-                 success_msg=u"You've reset your password successfully."):
-    form = Form(SetPasswordSchema(), buttons=('submit',))
+                 success_msg=_(u"You've reset your password successfully.")):
+    form = Form(SetPasswordSchema(), buttons=(Button('submit', _(u'Submit')),))
     rendered_form = None
 
     if 'submit' in request.POST:
         try:
             appstruct = form.validate(request.POST.items())
         except ValidationFailure, e:
-            request.session.flash(u"There was an error.", 'error')
+            request.session.flash(_(u"There was an error."), 'error')
             rendered_form = e.render()
         else:
             token = appstruct['token']
@@ -131,14 +132,15 @@ def set_password(context, request,
                 return HTTPFound(location=location, headers=headers)
             else:
                 request.session.flash(
-                    u"Your password reset token may have expired.", 'error')
+                    _(u"Your password reset token may have expired."), 'error')
 
     if rendered_form is None:
         rendered_form = form.render(request.params.items())
 
     api = template_api(
         context, request,
-        page_title=u"Reset your password - %s" % context.title,
+        page_title=_(u"Reset your password - ${title}",
+                     mapping=dict(title=context.title)),
         )
 
     return {
