@@ -1,10 +1,11 @@
+from kotti.util import _
 from kotti.util import ViewLink
 from kotti.views.util import template_api
 from kotti.views.util import is_root
 
 
 CONTROL_PANEL_LINKS = [
-    ViewLink('setup-users', u'User Management'),
+    ViewLink('setup-users', title=_(u'User Management')),
     ]
 
 def main(context, request):
@@ -12,9 +13,8 @@ def main(context, request):
         context, request,
         cp_links=CONTROL_PANEL_LINKS,
         )
-    api.page_title=u"Site Setup - %s" % api.site_title
-
-
+    api.page_title = _(u"Site Setup - ${title}",
+                       mapping=dict(title=api.site_title))
     return {'api': api}
 
 def includeme(config):
@@ -23,5 +23,5 @@ def includeme(config):
         name='setup',
         permission='admin',
         custom_predicates=(is_root,),
-        renderer='../templates/site-setup/main.pt',
+        renderer='kotti:templates/site-setup/main.pt',
         )
