@@ -24,10 +24,12 @@ from pyramid.threadlocal import get_current_request
 from pyramid.view import render_view_to_response
 from pyramid_deform import FormView
 from pyramid_deform import CSRFSchema
+from zope.deprecation import deprecated
 
 from kotti import get_settings
 from kotti import DBSession
 from kotti.util import _
+from kotti.util import disambiguate_name; disambiguate_name  # BBB
 from kotti.util import title_to_name
 from kotti.events import objectevent_listeners
 from kotti.resources import Content
@@ -185,12 +187,20 @@ class TemplateAPI(object):
             context = self.context
         return has_permission(permission, context, self.request)
 
-    def render_view(self, name='', context=None, request=None, secure=True):
+    def render_view(self, name='', context=None, request=None, secure=True,
+                    bare=True):
         if context is None:
             context = self.context
         if request is None:
             request = self.request
-        return TemplateStructure(render_view(context, request, name, secure))
+
+        before = self.bare
+        try:
+            self.bare = bare
+            html = render_view(context, request, name, secure)
+        finally:
+            self.bare = before
+        return TemplateStructure(html)
 
     def render_template(self, renderer, **kwargs):
         return TemplateStructure(render(renderer, kwargs, self.request))
@@ -266,19 +276,6 @@ class TemplateAPI(object):
                 if l.permitted(self.context, self.request)]
 
 
-def disambiguate_name(name):
-    parts = name.split(u'-')
-    if len(parts) > 1:
-        try:
-            index = int(parts[-1])
-        except ValueError:
-            parts.append(u'1')
-        else:
-            parts[-1] = unicode(index + 1)
-    else:
-        parts.append(u'1')
-    return u'-'.join(parts)
-
 def ensure_view_selector(func):
     def wrapper(context, request):
         path_els = request.path_info.split(u'/')
@@ -363,7 +360,9 @@ class BaseFormView(FormView):
         return result
 
     def cancel_success(self, appstruct):
-        return HTTPFound(location=self.request.url)
+        location = self.request.resource_url(self.context)
+        return HTTPFound(location=location)
+    cancel_failure = cancel_success
 
     def more_template_vars(self):
         result = {}
@@ -371,11 +370,27 @@ class BaseFormView(FormView):
             result[name] = getattr(self, name)
         return result
 
+def get_appstruct(context, schema):
+    appstruct = {}
+    for field in schema.children:
+        if hasattr(context, field.name):
+            appstruct[field.name] = getattr(context, field.name)
+    return appstruct
+
+def appstruct(context, schema):  # pragma: no cover
+    return get_appstruct(context, schema)
+
+deprecated(
+    'appstruct',
+    'appstruct is deprecated as of Kotti 0.6.2.  Use '
+    '``kotti.views.util.get_appstruct`` instead.'
+    )
+
 class EditFormView(BaseFormView):
     add_template_vars = ('first_heading',)
 
     def before(self, form):
-        form.appstruct = self.context.__dict__.copy()
+        form.appstruct = appstruct(self.context, self.schema)
 
     def save_success(self, appstruct):
         appstruct.pop('csrf_token', None)
@@ -391,7 +406,7 @@ class EditFormView(BaseFormView):
     @reify
     def first_heading(self):
         return _(u'Edit <em>${title}</em>',
-                 mapping=dict(title=self.request.context.title)
+                 mapping=dict(title=self.context.title)
                  )
 
 class AddFormView(BaseFormView):
@@ -410,9 +425,8 @@ class AddFormView(BaseFormView):
     def find_name(self, appstruct):
         name = appstruct.get('name')
         if name is None:
-            name = title_to_name(appstruct['title'])
-            while name in self.context.keys():
-                name = disambiguate_name(name)
+            name = title_to_name(
+                appstruct['title'], blacklist=self.context.keys())
         return name
 
     @reify
@@ -425,3 +439,10 @@ class AddFormView(BaseFormView):
                 mapping=dict(type=translate(type_title), title=context_title))
         else:
             return _(u'Add ${type}', mapping=dict(type=translate(type_title)))
+
+
+deprecated(
+    'disambiguate_name',
+    'disambiguate_name is deprecated as of Kotti 0.6.2.  Use '
+    '``kotti.util.disambiguate_name`` instead.'
+    )
